@@ -75,6 +75,12 @@ class CUPSDAT(object):
         """
         :return: file path of generated CUPSDAT File
         """
+        existing_files = os.listdir('/tmp')
+        if existing_files:
+            versions = [int(f.split('.')[1]) for f in existing_files if self.filename.split('.')[0] in f]
+            if versions:
+                self.version = max(versions) + 1
+
         file_path = os.path.join('/tmp', self.filename)
 
         kwargs = {'sep': ';',
